=====
Neko
=====
.. image:: https://travis-ci.org/sudaning/PytLab-Neko.svg?branch=master
	:target: https://travis-ci.org/sudaning/PytLab-Neko
	:alt: Build Status
.. image:: https://img.shields.io/badge/python-3.5-green.svg
	:target: https://www.python.org/downloads/release/python-351/
	:alt: platform
.. image:: https://img.shields.io/badge/python-2.7-green.svg
	:target: https://www.python.org/downloads/release/python-2710
	:alt: platform
.. image:: https://img.shields.io/github/stars/sudaning/PytLab-Neko.svg
	:target: https://github.com/sudaning/PytLab-Neko/stargazers
.. image:: https://img.shields.io/github/forks/sudaning/PytLab-Neko.svg
	:target: https://github.com/sudaning/PytLab-Neko/network
Introduction
------------
pyNeko is a pure Python library designed to making magic to code for Neko.
You can use pyNeko to making magic beautiful.
In `/scripts <https://github.com/sudaning/PytLab-Neko/tree/master/scripts>`_ , there are some scripts written by me for daily use.
Installation
------------
1. Via pip(recommend)::
	pip install pyNeko
2. Via easy_install::
	easy_install pyNeko
3. From source::
	python setup.py install